<?php

namespace Drupal\modal_page\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Class: ModalForm.
 */
class ModalForm extends ContentEntityForm {

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form = parent::buildForm($form, $form_state);
    $entity = $this->entity;

    $default_language = $entity->getUntranslated()->language()->getId();

    if (!empty($entity->langcode->value)) {
      $default_language = $entity->langcode->value;
    }

    // @codingStandardsIgnoreLine
    $languages = \Drupal::languageManager()->getCurrentLanguage();

    $form['langcode'] = [
      '#title' => $this->t('Language'),
      '#type' => 'language_select',
      '#default_value' => $default_language,
      '#empty_option' => $this->t('- Any -'),
    ];

    if ($this->isMonoLanguage($languages)) {
      $disabled = ['disabled' => 'disabled'];
      $form['langcode']['#attributes'] = $disabled;
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function isMonoLanguage($languages) {
    if (empty($languages)) {
      return FALSE;
    }

    if (!is_array($languages) || !is_object($languages)) {
      return FALSE;
    }

    if (count($languages) != 1) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    drupal_flush_all_caches();
    drupal_set_message($this->t('Completed'));

    $values = $form_state->getValues();

    $type = $values['type'];
    $type = current($type);
    $type = $type['value'];

    if (!empty($type) && $type == 'page') {

      $pages = $values['pages'];
      $pages = current($pages);
      $pages = $pages['value'];

      $pages = explode(PHP_EOL, $pages);

      $page = current($pages);

      $host = Url::fromRoute('<front>', [], ['absolute' => TRUE])->toString();

      $url_modal = $host . $page;

      drupal_set_message($this->t('You may <a target="blank" href="@url_modal">See Modal</a>', [
        '@url_modal' => $url_modal,
      ]));
    }

    $form_state->setRedirect('modal_page.default');
    $entity = $this->getEntity();
    $entity->save();
  }

}
